Module: GithubPolyglot::SVG::LanguageStats

Included in:
GithubPolyglot::SVG
Defined in:
lib/github_polyglot/svg/language_stats.rb

Overview

Helper for language stats

Constant Summary collapse

TOP_LANGUAGES =

The number of the most popular languages to show. If there are more than this amount of languages, the least common get grouped under “Other” languages.

6
STATS_COLUMNS =

The number of columns in the language stats area.

2
STAT_ROW_HEIGHT =

The height of a language stat row.

20
LANGUAGE_NAME_CLASS =

Classes for the language name in language stats.

'text-bold'
LANGUAGE_PERCENTAGE_CLASS =

Class for the language percentage.

'muted'